import 'package:firebase/models/movie_model_firebase.dart';
import 'package:firebase/models/rating_state.dart';
import 'package:firebase_auth/firebase_auth.dart';
import 'package:flutter/material.dart';
import 'package:flutter_rating_bar/flutter_rating_bar.dart';

import 'models/movie_model.dart';

class MovieDetail extends StatelessWidget {
  late final String? _editingMovieId;
  final RatingState _rating = RatingState();
  final TextEditingController _nameController = TextEditingController();
  final TextEditingController _addedByController = TextEditingController();
  final TextEditingController _reviewController = TextEditingController();

  MovieDetail({Key? key, MovieModel? movieModel}) : super(key: key) {
    if (movieModel != null) {
      _rating.value = movieModel.rating;
      _nameController.text = movieModel.name;
      _addedByController.text = movieModel.addedBy;
      _reviewController.text = movieModel.review;
    }
    // TODO add automatic name
    _editingMovieId = movieModel?.id;
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(
          _nameController.text.isEmpty ? 'Add Movie' : 'Movie detail',
        ),
      ),
      body: Column(
        mainAxisSize: MainAxisSize.max,
        children: [
          const SizedBox(height: 15.0),
          _buildTextField(_nameController, 'Movie name', 1),
          _buildTextField(_addedByController, 'Added by', 1),
          _buildTextField(_reviewController, 'Description', 10),
          _buildRatingRow(),
          Padding(
            padding: const EdgeInsets.all(10.0),
            child: _buildTextButton(context),
          ),
        ],
      ),
    );
  }

  Row _buildRatingRow() {
    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceEvenly,
      children: [
        const Text(
          'Rating',
          style: TextStyle(
            fontSize: 18,
          ),
        ),
        RatingBar.builder(
          initialRating: _rating.value,
          minRating: 0,
          direction: Axis.horizontal,
          allowHalfRating: true,
          itemCount: 5,
          itemPadding: const EdgeInsets.symmetric(horizontal: 4.0),
          itemBuilder: (context, _) => const Icon(
            Icons.star,
            color: Colors.blueAccent,
          ),
          onRatingUpdate: (rating) {
            _rating.value = rating;
          },
        ),
      ],
    );
  }

  Widget _buildTextField(
      TextEditingController controller, String label, int maxLines) {
    return Padding(
      padding: const EdgeInsets.all(5.0),
      child: TextField(
        controller: controller,
        maxLines: maxLines,
        decoration: InputDecoration(
          label: Text(label),
          border: const OutlineInputBorder(),
        ),
      ),
    );
  }

  TextButton _buildTextButton(BuildContext context) {
    return TextButton(
      child: Text(
        _nameController.text.isEmpty ? 'Add movie' : 'Edit Movie',
        style: const TextStyle(
          fontSize: 18.0,
          color: Colors.white,
        ),
      ),
      onPressed: () {
        // TODO add/edit movie
        Navigator.of(context).pop();
      },
      style: ButtonStyle(
        backgroundColor: MaterialStateProperty.all(Colors.blueAccent),
      ),
    );
  }
}
